/* Copyright (C) 2017 by Bundesanstalt für Gewässerkunde
 * Software engineering by
 *  Björnsen Beratende Ingenieure GmbH
 *  Dr. Schumacher Ingenieurbüro für Wasser und Umwelt
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */

package org.dive4elements.river.importer.uinfo.importitem;

import java.util.List;

import org.apache.log4j.Logger;
import org.dive4elements.river.importer.common.AbstractSeriesImport;
import org.dive4elements.river.model.River;
import org.dive4elements.river.model.uinfo.Vegetation;
import org.dive4elements.river.model.uinfo.VegetationZone;
import org.hibernate.Query;
import org.hibernate.Session;

/**
 * Imported vegetation data series of a river
 *
 * @author Matthias Schäfer
 *
 */
public class VegetationSeriesImport extends AbstractSeriesImport<Vegetation, VegetationZone, VegetationZoneImport> {

    /***** FIELDS *****/

    private static Logger log = Logger.getLogger(VegetationSeriesImport.class);

    private String name;


    /***** CONSTRUCTORS *****/

    public VegetationSeriesImport(final String filename) {
        super(filename);
    }


    /***** METHODS *****/

    public void setName(final String name) {
        this.name = name;
    }

    @Override
    public Logger getLog() {
        return log;
    }

    @Override
    public List<Vegetation> querySeriesItem(final Session session, final River river, final boolean doQueryParent) {
        final Query query = session.createQuery("FROM Vegetation WHERE river=:river");
        query.setParameter("river", river);
        return query.list();
    }


    @Override
    public Vegetation createSeriesItem(final River river) {
        return new Vegetation(river, this.filename, this.name, this.notes);
    }
}